==> atom-check-updates-0.1.1.tgz: package/lib/acu.js <==
'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _symbol = require('babel-runtime/core-js/symbol');

var _symbol2 = _interopRequireDefault(_symbol);

var _distro;

var detectDistro = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return new _promise2.default(function (resolve, reject) {
              // TODO: something less ugly?
              try {
                (0, _child_process.execFileSync)('/usr/bin/dpkg', ['-S', '/usr/bin/dpkg']);

                return resolve(distro[DISTRO_DEBIAN]);
              } catch (err) {
                try {
                  (0, _child_process.execFileSync)('/usr/bin/rpm', ['-q', '-f', '/usr/bin/rpm']);

                  return resolve(distro[DISTRO_RPM]);
                } catch (err) {
                  return resolve(false);
                }
              }
            });

          case 2:
            return _context.abrupt('return', _context.sent);

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return function detectDistro() {
    return ref.apply(this, arguments);
  };
}();

var getCurrentVersion = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return new _promise2.default(function (resolve, reject) {
              (0, _child_process.execFile)(bin, ['--version'], function (error, stdout, stderr) {
                if (error || stderr) return resolve(null);

                var version = stdout.match(/^Atom\s+:\s+(\d\.\d\.\d(?:-\w+\d+)?)$/m);

                resolve(version[1]);
              });
            });

          case 2:
            return _context2.abrupt('return', _context2.sent);

          case 3:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));
  return function getCurrentVersion() {
    return ref.apply(this, arguments);
  };
}();

var getLatestVersion = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var opts = {
                url: RELEASES_API,
                headers: { 'User-Agent': USER_AGENT },
                json: true
              };

              (0, _request2.default)(opts, function (err, res, body) {
                if (err) return reject(err);

                var release = body.find(function (release) {
                  return release.prerelease === !!_commander2.default.beta;
                });

                resolve(release.name);
              });
            });

          case 2:
            return _context3.abrupt('return', _context3.sent);

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));
  return function getLatestVersion() {
    return ref.apply(this, arguments);
  };
}();

var getChangelog = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4(version) {
    return _regenerator2.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var opts = {
                url: 'https://git.io',
                method: 'post',
                form: { url: RELEASE_URL + '/v' + version },
                headers: { 'User-Agent': USER_AGENT }
              };

              (0, _request2.default)(opts, function (err, res, body) {
                if (err) return reject(err);

                resolve(res.headers['location']);
              });
            });

          case 2:
            return _context4.abrupt('return', _context4.sent);

          case 3:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, this);
  }));
  return function getChangelog(_x) {
    return ref.apply(this, arguments);
  };
}();

var download = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee5(version, distro) {
    var good, info;
    return _regenerator2.default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            good = format.good;
            info = format.info;
            _context5.next = 4;
            return new _promise2.default(function (resolve, reject) {
              var file = distro.file;


              var opts = {
                url: DOWNLOAD_URL + '/v' + version + '/' + file,
                headers: { 'User-Agent': USER_AGENT }
              };

              try {
                _fs2.default.accessSync(TEMP_FOLDER, _fs2.default.W_OK);
              } catch (err) {
                if (err.code === 'ENOENT') {
                  _fs2.default.mkdirSync(TEMP_FOLDER);
                } else {
                  throw err;
                }
              }

              var dest = _path2.default.join(TEMP_FOLDER, version + '-' + file);
              var req = (0, _request2.default)(opts);

              req.on('response', function (res) {
                var len = parseInt(res.headers['content-length'], 10);
                var tmpl = ' - ' + file + ' [:bar] :percent ' + info(':etas');
                var bar = new _progress2.default(tmpl, {
                  complete: good('='),
                  incomplete: ' ',
                  width: 40,
                  total: len
                });

                res.on('data', function (chunk) {
                  return bar.tick(chunk.length);
                });
                res.on('end', function () {
                  return resolve(dest);
                });
              });

              req.on('error', function (err) {
                return reject(err);
              });

              req.pipe(_fs2.default.createWriteStream(dest));
            });

          case 4:
            return _context5.abrupt('return', _context5.sent);

          case 5:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, this);
  }));
  return function download(_x2, _x3) {
    return ref.apply(this, arguments);
  };
}();

var install = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee6(file, distro) {
    return _regenerator2.default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var cmd = distro.cmd;


              var dpkg = (0, _child_process.spawn)('sudo', [].concat((0, _toConsumableArray3.default)(cmd), [file]), {
                stdio: ['ignore', 'inherit', 'inherit']
              });

              dpkg.on('error', function (err) {
                return reject(err);
              });
              dpkg.on('exit', function (res) {
                return resolve(res);
              });
            });

          case 2:
            return _context6.abrupt('return', _context6.sent);

          case 3:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, this);
  }));
  return function install(_x4, _x5) {
    return ref.apply(this, arguments);
  };
}();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _progress = require('progress');

var _progress2 = _interopRequireDefault(_progress);

var _child_process = require('child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pkg = require(_path2.default.join(__dirname, '../package.json'));

_commander2.default.option('-b, --beta', 'Check for beta releases').option('-y, --force-yes', 'Update without user confirmation').parse(process.argv);

var RELEASES_API = 'https://api.github.com/repos/atom/atom/releases';
var DOWNLOAD_URL = 'https://github.com/atom/atom/releases/download';
var RELEASE_URL = 'https://github.com/atom/atom/releases/tag';
var USER_AGENT = 'atom-check-updates/' + pkg.version;
var TEMP_FOLDER = '/tmp/acu';
var DISTRO_DEBIAN = (0, _symbol2.default)('deb');
var DISTRO_RPM = (0, _symbol2.default)('rpm');

var distro = (_distro = {}, (0, _defineProperty3.default)(_distro, DISTRO_DEBIAN, {
  name: 'Debian',
  file: 'atom-amd64.deb',
  cmd: ['dpkg', '-i']
}), (0, _defineProperty3.default)(_distro, DISTRO_RPM, {
  name: 'RPM',
  file: 'atom.x86_64.rpm',
  cmd: ['rpm', '-Uvh']
}), _distro);

var bin = _commander2.default.beta ? 'atom-beta' : 'atom';
var log = console.log.bind(console);

var format = {
  intro: _chalk2.default.bgMagenta.bold,
  headline: _chalk2.default.green.bold.underline,
  info: _chalk2.default.dim.italic,
  text: _chalk2.default.white.bold,
  good: _chalk2.default.green.bold,
  bad: _chalk2.default.red.bold,
  success: _chalk2.default.bgGreen.bold,
  error: _chalk2.default.bgRed.bold,
  warning: _chalk2.default.bgYellow.bold
};

module.exports = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee7() {
    var releaseType, intro, info, headline, text, success, warning, error, distro, current, latest, changelog, answer, file, result;
    return _regenerator2.default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            releaseType = _commander2.default.beta ? 'beta' : 'stable';
            intro = format.intro;
            info = format.info;
            headline = format.headline;
            text = format.text;
            success = format.success;
            warning = format.warning;
            error = format.error;


            log(intro('  ✨ atom-check-updates v%s ✨  '), pkg.version, '\n');

            log(info('Retrieving information about your distro...'));

            _context7.next = 12;
            return detectDistro();

          case 12:
            distro = _context7.sent;


            if (!distro) {
              log(error('You don\'t seem to be running a supported distro'));

              process.exit(1);
            }

            log(text('- Detected as running on a %s-based distro.'), distro.name, '\n');

            log(info('Checking for installed') + ' ' + info.bold(releaseType) + ' ' + info('version...'));

            _context7.next = 18;
            return getCurrentVersion();

          case 18:
            current = _context7.sent;


            log(headline('Current version:'));
            log(text('  - %s'), current || 'None, or older than 1.7.0', '\n');

            log(info('Checking for latest') + ' ' + info.bold(releaseType) + ' ' + info('release...'));

            _context7.next = 24;
            return getLatestVersion();

          case 24:
            latest = _context7.sent;
            _context7.next = 27;
            return getChangelog(latest);

          case 27:
            changelog = _context7.sent;


            log(headline('Latest version:'));
            log(text('  - %s'), latest, '(changelog: ' + changelog + ')\n');

            if (current === latest) {
              log(success('You\'re already on the latest version!'));

              process.exit(0);
            }

            log(warning('An update is available!'));

            if (_commander2.default.forceYes) {
              _context7.next = 37;
              break;
            }

            _context7.next = 35;
            return _inquirer2.default.prompt([{
              type: 'confirm',
              name: 'confirm',
              message: 'Upgrade to v' + latest + '?',
              default: false
            }]);

          case 35:
            answer = _context7.sent;


            if (!answer.confirm) {
              log(error('Installation aborted!'));

              process.exit(1);
            }

          case 37:

            log(headline('Downloading:'));

            _context7.prev = 38;
            _context7.next = 41;
            return download(latest, distro);

          case 41:
            file = _context7.sent;
            _context7.next = 44;
            return install(file, distro);

          case 44:
            result = _context7.sent;


            if (result === 0) {
              log(success('Installation completed successfully!'));

              _fs2.default.unlinkSync(file);

              process.exit(0);
            }
            _context7.next = 53;
            break;

          case 48:
            _context7.prev = 48;
            _context7.t0 = _context7['catch'](38);

            log(error('An unexpected error occured'));
            log(info(_context7.t0.toString()));

            process.exit(1);

          case 53:

            log(error('An unknown error occured'));

            process.exit(1);

          case 55:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, this, [[38, 48]]);
  }));

  function init() {
    return ref.apply(this, arguments);
  }

  return init;
}();

==> atom-check-updates-0.1.2.tgz: package/lib/acu.js <==
'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _symbol = require('babel-runtime/core-js/symbol');

var _symbol2 = _interopRequireDefault(_symbol);

var _distro;

var detectDistro = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return new _promise2.default(function (resolve, reject) {
              // TODO: something less ugly?
              try {
                (0, _child_process.execFileSync)('/usr/bin/dpkg', ['-S', '/usr/bin/dpkg']);

                return resolve(distro[DISTRO_DEBIAN]);
              } catch (err) {
                try {
                  (0, _child_process.execFileSync)('/usr/bin/rpm', ['-q', '-f', '/usr/bin/rpm']);

                  return resolve(distro[DISTRO_RPM]);
                } catch (err) {
                  return resolve(false);
                }
              }
            });

          case 2:
            return _context.abrupt('return', _context.sent);

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return function detectDistro() {
    return ref.apply(this, arguments);
  };
}();

var getCurrentVersion = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return new _promise2.default(function (resolve, reject) {
              (0, _child_process.execFile)(bin, ['--version'], function (error, stdout, stderr) {
                if (error || stderr) return resolve(null);

                var version = stdout.match(/^Atom\s+:\s+(\d+\.\d+\.\d+(?:-\w+\d+)?)$/m);

                resolve(version[1]);
              });
            });

          case 2:
            return _context2.abrupt('return', _context2.sent);

          case 3:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));
  return function getCurrentVersion() {
    return ref.apply(this, arguments);
  };
}();

var getLatestVersion = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var opts = {
                url: RELEASES_API,
                headers: { 'User-Agent': USER_AGENT },
                json: true
              };

              (0, _request2.default)(opts, function (err, res, body) {
                if (err) return reject(err);

                var release = body.find(function (release) {
                  return release.prerelease === !!_commander2.default.beta;
                });

                resolve(release.name);
              });
            });

          case 2:
            return _context3.abrupt('return', _context3.sent);

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));
  return function getLatestVersion() {
    return ref.apply(this, arguments);
  };
}();

var getChangelog = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4(version) {
    return _regenerator2.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var opts = {
                url: 'https://git.io',
                method: 'post',
                form: { url: RELEASE_URL + '/v' + version },
                headers: { 'User-Agent': USER_AGENT }
              };

              (0, _request2.default)(opts, function (err, res, body) {
                if (err) return reject(err);

                resolve(res.headers['location']);
              });
            });

          case 2:
            return _context4.abrupt('return', _context4.sent);

          case 3:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, this);
  }));
  return function getChangelog(_x) {
    return ref.apply(this, arguments);
  };
}();

var download = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee5(version, distro) {
    var good, info;
    return _regenerator2.default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            good = format.good;
            info = format.info;
            _context5.next = 4;
            return new _promise2.default(function (resolve, reject) {
              var file = distro.file;


              var opts = {
                url: DOWNLOAD_URL + '/v' + version + '/' + file,
                headers: { 'User-Agent': USER_AGENT }
              };

              try {
                _fs2.default.accessSync(TEMP_FOLDER, _fs2.default.W_OK);
              } catch (err) {
                if (err.code === 'ENOENT') {
                  _fs2.default.mkdirSync(TEMP_FOLDER);
                } else {
                  throw err;
                }
              }

              var dest = _path2.default.join(TEMP_FOLDER, version + '-' + file);
              var req = (0, _request2.default)(opts);

              req.on('response', function (res) {
                var len = parseInt(res.headers['content-length'], 10);
                var tmpl = ' - ' + file + ' [:bar] :percent ' + info(':etas');
                var bar = new _progress2.default(tmpl, {
                  complete: good('='),
                  incomplete: ' ',
                  width: 40,
                  total: len
                });

                res.on('data', function (chunk) {
                  return bar.tick(chunk.length);
                });
                res.on('end', function () {
                  return resolve(dest);
                });
              });

              req.on('error', function (err) {
                return reject(err);
              });

              req.pipe(_fs2.default.createWriteStream(dest));
            });

          case 4:
            return _context5.abrupt('return', _context5.sent);

          case 5:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, this);
  }));
  return function download(_x2, _x3) {
    return ref.apply(this, arguments);
  };
}();

var install = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee6(file, distro) {
    return _regenerator2.default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.next = 2;
            return new _promise2.default(function (resolve, reject) {
              var cmd = distro.cmd;


              var dpkg = (0, _child_process.spawn)('sudo', [].concat((0, _toConsumableArray3.default)(cmd), [file]), {
                stdio: ['ignore', 'inherit', 'inherit']
              });

              dpkg.on('error', function (err) {
                return reject(err);
              });
              dpkg.on('exit', function (res) {
                return resolve(res);
              });
            });

          case 2:
            return _context6.abrupt('return', _context6.sent);

          case 3:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, this);
  }));
  return function install(_x4, _x5) {
    return ref.apply(this, arguments);
  };
}();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _progress = require('progress');

var _progress2 = _interopRequireDefault(_progress);

var _child_process = require('child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pkg = require(_path2.default.join(__dirname, '../package.json'));

_commander2.default.option('-b, --beta', 'Check for beta releases').option('-y, --force-yes', 'Update without user confirmation').parse(process.argv);

var RELEASES_API = 'https://api.github.com/repos/atom/atom/releases';
var DOWNLOAD_URL = 'https://github.com/atom/atom/releases/download';
var RELEASE_URL = 'https://github.com/atom/atom/releases/tag';
var USER_AGENT = 'atom-check-updates/' + pkg.version;
var TEMP_FOLDER = '/tmp/acu';
var DISTRO_DEBIAN = (0, _symbol2.default)('deb');
var DISTRO_RPM = (0, _symbol2.default)('rpm');

var distro = (_distro = {}, (0, _defineProperty3.default)(_distro, DISTRO_DEBIAN, {
  name: 'Debian',
  file: 'atom-amd64.deb',
  cmd: ['dpkg', '-i']
}), (0, _defineProperty3.default)(_distro, DISTRO_RPM, {
  name: 'RPM',
  file: 'atom.x86_64.rpm',
  cmd: ['rpm', '-Uvh']
}), _distro);

var bin = _commander2.default.beta ? 'atom-beta' : 'atom';
var log = console.log.bind(console);

var format = {
  intro: _chalk2.default.bgMagenta.bold,
  headline: _chalk2.default.green.bold.underline,
  info: _chalk2.default.dim.italic,
  text: _chalk2.default.white.bold,
  good: _chalk2.default.green.bold,
  bad: _chalk2.default.red.bold,
  success: _chalk2.default.bgGreen.bold,
  error: _chalk2.default.bgRed.bold,
  warning: _chalk2.default.bgYellow.bold
};

module.exports = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee7() {
    var releaseType, intro, info, headline, text, success, warning, error, distro, current, latest, changelog, answer, file, result;
    return _regenerator2.default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            releaseType = _commander2.default.beta ? 'beta' : 'stable';
            intro = format.intro;
            info = format.info;
            headline = format.headline;
            text = format.text;
            success = format.success;
            warning = format.warning;
            error = format.error;


            log(intro('  ✨ atom-check-updates v%s ✨  '), pkg.version, '\n');

            log(info('Retrieving information about your distro...'));

            _context7.next = 12;
            return detectDistro();

          case 12:
            distro = _context7.sent;


            if (!distro) {
              log(error('You don\'t seem to be running a supported distro'));

              process.exit(1);
            }

            log(text('- Detected as running on a %s-based distro.'), distro.name, '\n');

            log(info('Checking for installed') + ' ' + info.bold(releaseType) + ' ' + info('version...'));

            _context7.next = 18;
            return getCurrentVersion();

          case 18:
            current = _context7.sent;


            log(headline('Current version:'));
            log(text('  - %s'), current || 'None, or older than 1.7.0', '\n');

            log(info('Checking for latest') + ' ' + info.bold(releaseType) + ' ' + info('release...'));

            _context7.next = 24;
            return getLatestVersion();

          case 24:
            latest = _context7.sent;
            _context7.next = 27;
            return getChangelog(latest);

          case 27:
            changelog = _context7.sent;


            log(headline('Latest version:'));
            log(text('  - %s'), latest, '(changelog: ' + changelog + ')\n');

            if (current === latest) {
              log(success('You\'re already on the latest version!'));

              process.exit(0);
            }

            log(warning('An update is available!'));

            if (_commander2.default.forceYes) {
              _context7.next = 37;
              break;
            }

            _context7.next = 35;
            return _inquirer2.default.prompt([{
              type: 'confirm',
              name: 'confirm',
              message: 'Upgrade to v' + latest + '?',
              default: false
            }]);

          case 35:
            answer = _context7.sent;


            if (!answer.confirm) {
              log(error('Installation aborted!'));

              process.exit(1);
            }

          case 37:

            log(headline('Downloading:'));

            _context7.prev = 38;
            _context7.next = 41;
            return download(latest, distro);

          case 41:
            file = _context7.sent;
            _context7.next = 44;
            return install(file, distro);

          case 44:
            result = _context7.sent;


            if (result === 0) {
              log(success('Installation completed successfully!'));

              _fs2.default.unlinkSync(file);

              process.exit(0);
            }
            _context7.next = 53;
            break;

          case 48:
            _context7.prev = 48;
            _context7.t0 = _context7['catch'](38);

            log(error('An unexpected error occured'));
            log(info(_context7.t0.toString()));

            process.exit(1);

          case 53:

            log(error('An unknown error occured'));

            process.exit(1);

          case 55:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, this, [[38, 48]]);
  }));

  function init() {
    return ref.apply(this, arguments);
  }

  return init;
}();
